# 0.0.5
- macro.run: return existing output_files even if macro empty

# 0.0.4
- macro.stitch: support for 16 bit images

# 0.0.3
- add fijibin.macro

# 0.0.2
- use 64-bit Fiji if operating system is 64-bit

# 0.0.1
- use `BIN` as variable name
- chmod +x for bin_names after fetch
- VERSION -> FIJI_VERSION
- use Fiji version name
  - Fiji.app -> Fiji-20141125.app

# 2014.11.25 (removed from pypi)
- initial version
